#[non_exhaustive]pub enum KappaError {
BufferTooSmall {
needed: usize,
offered: usize,
},
MalformedDigest,
NotAddressable,
}Expand description
The manifest could not be rendered or addressed.
Neither variant can be caused by the values in a matrix, only by a
manifest that does not describe an artifact. Like [uor_matmul_core:: NotAProduct], this is non-existence, decided before any arithmetic.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BufferTooSmall
The caller’s buffer is too small for the canonical JSON.
MalformedDigest
A digest field is not a sha256:<64hex> string.
NotAddressable
The addressing transform rejected the manifest.